pub struct PasswordHash {
pub value: String,
}Expand description
PasswordHash : This is stored as an PHC password string. This type corresponds to the string representation of a PHC string as described in the [PHC string format specification][1]. PHC strings have the following format: text $<id>[$v=<version>][$<param>=<value>(,<param>=<value>)*][$<salt>[$<hash>]]
Fields
value: StringImplementations
Sourceimpl PasswordHash
impl PasswordHash
Sourcepub fn new(value: String) -> PasswordHash
pub fn new(value: String) -> PasswordHash
This is stored as an PHC password string. This type corresponds to the string representation of a PHC string as described in the [PHC string format specification][1]. PHC strings have the following format: text $<id>[$v=<version>][$<param>=<value>(,<param>=<value>)*][$<salt>[$<hash>]]