pub struct Timer {
pub name: Option<String>,
pub quantity: Option<UnitAmount>,
}Expand description
Timer : A recipe timer If created from parsing, at least one of the fields is guaranteed to be Some.
Fields
name: Option<String>Name
quantity: Option<UnitAmount>Time quantity
Implementations