pub struct Unit {
pub description: Option<String>,
pub full_name_plural: String,
pub full_name_singular: String,
pub id: UnitId,
pub short_name: String,
pub unit_property: UnitPropertyId,
}Fields
description: Option<String>Description of this unit.
full_name_plural: StringThe plural version of this unit’s name. Is used by a value of two and more. (We do not support Slovenian dual numerus versions) E.g.: Kilogram -> Kilograms gram -> meters
full_name_singular: StringThe singular version of this unit’s name. E.g.: Kilogram Gram
id: UnitIdUnique id for this unit.
short_name: StringShort name or abbreviation of this unit. E.g.: kg for Kilogram g for gram m for meter
unit_property: UnitPropertyIdWhich property is described by this unit. E.g.: kg -> Mass L -> Volume m/s -> Speed and so forth
Implementations