pub struct UnitProperty {
pub description: Option<String>,
pub id: UnitPropertyId,
pub name: String,
pub units: Vec<UnitId>,
}Expand description
UnitProperty : An unit property describes a property that can be measured by units. For example velocity, mass or volume.
Fields
description: Option<String>An description of this property.
id: UnitPropertyIdThe unique ID for this unit property.
name: StringThe user-displayed name of this property.
units: Vec<UnitId>The units with are measuring this property.
Implementations
Sourceimpl UnitProperty
impl UnitProperty
Sourcepub fn new(id: UnitPropertyId, name: String, units: Vec<UnitId>) -> UnitProperty
pub fn new(id: UnitPropertyId, name: String, units: Vec<UnitId>) -> UnitProperty
An unit property describes a property that can be measured by units. For example velocity, mass or volume.